@@ -32,6 +32,16 @@
 #include <errno.h>
 #include <stdlib.h>
 
+static char *
+render_val (double val, GOFormat const *fmt)
+{
+	if (fmt)
+		return go_format_value (fmt, val);
+	else
+		return g_strdup_printf ("%g", val);
+}
+
+
 struct _GODataScalarVal {
 	GODataScalar	 base;
 	double		 val;
@@ -72,13 +82,14 @@ go_data_scalar_val_eq (GOData const *a, GOData const *b)
 }
 
 static char *
-go_data_scalar_val_as_str (GOData const *dat)
+go_data_scalar_val_serialize (GOData const *dat, gpointer user)
 {
+	/* FIXME: shouldn't use _get_str.  */
 	return g_strdup (go_data_scalar_get_str (GO_DATA_SCALAR (dat)));
 }
 
 static gboolean
-go_data_scalar_val_from_str (GOData *dat, char const *str)
+go_data_scalar_val_unserialize (GOData *dat, char const *str, gpointer user)
 {
 	GODataScalarVal *sval = (GODataScalarVal *)dat;
 	double tmp;
@@ -106,9 +117,10 @@ static char const *
 go_data_scalar_val_get_str (GODataScalar *dat)
 {
 	GODataScalarVal *sval = (GODataScalarVal *)dat;
+	GOFormat const *fmt = NULL;
 
 	if (sval->str == NULL)
-		sval->str = g_strdup_printf ("%g", sval->val);
+		sval->str = render_val (sval->val, fmt);
 	return sval->str;
 }
 
@@ -118,24 +130,24 @@ go_data_scalar_val_class_init (GObjectClass *gobject_klass)
 	GODataClass *godata_klass = (GODataClass *) gobject_klass;
 	GODataScalarClass *scalar_klass = (GODataScalarClass *) gobject_klass;
 
-	scalar_val_parent_klass = g_type_class_peek_parent (gobject_klass);
-	gobject_klass->finalize = go_data_scalar_val_finalize;
-	godata_klass->dup	= go_data_scalar_val_dup;
-	godata_klass->eq	= go_data_scalar_val_eq;
-	godata_klass->as_str	= go_data_scalar_val_as_str;
-	godata_klass->from_str	= go_data_scalar_val_from_str;
-	scalar_klass->get_value	= go_data_scalar_val_get_value;
-	scalar_klass->get_str	= go_data_scalar_val_get_str;
+	scalar_val_parent_klass   = g_type_class_peek_parent (gobject_klass);
+	gobject_klass->finalize   = go_data_scalar_val_finalize;
+	godata_klass->dup	  = go_data_scalar_val_dup;
+	godata_klass->eq	  = go_data_scalar_val_eq;
+	godata_klass->serialize	  = go_data_scalar_val_serialize;
+	godata_klass->unserialize = go_data_scalar_val_unserialize;
+	scalar_klass->get_value	  = go_data_scalar_val_get_value;
+	scalar_klass->get_str	  = go_data_scalar_val_get_str;
 }
 
 GSF_CLASS (GODataScalarVal, go_data_scalar_val,
 	   go_data_scalar_val_class_init, NULL,
-	   GO_DATA_SCALAR_TYPE)
+	   GO_TYPE_DATA_SCALAR)
 
 GOData *
 go_data_scalar_val_new (double val)
 {
-	GODataScalarVal *res = g_object_new (GO_DATA_SCALAR_VAL_TYPE, NULL);
+	GODataScalarVal *res = g_object_new (GO_TYPE_DATA_SCALAR_VAL, NULL);
 	res->val = val;
 	return GO_DATA (res);
 }
@@ -182,14 +194,14 @@ go_data_scalar_str_eq (GOData const *a, GOData const *b)
 }
 
 static char *
-go_data_scalar_str_as_str (GOData const *dat)
+go_data_scalar_str_serialize (GOData const *dat, gpointer user)
 {
 	GODataScalarStr const *str = (GODataScalarStr const *)dat;
 	return g_strdup (str->str);
 }
 
 static gboolean
-go_data_scalar_str_from_str (GOData *dat, char const *string)
+go_data_scalar_str_unserialize (GOData *dat, char const *string, gpointer user)
 {
 	GODataScalarStr *str = (GODataScalarStr *)dat;
 
@@ -225,8 +237,8 @@ go_data_scalar_str_class_init (GObjectClass *gobject_klass)
 	gobject_klass->finalize	= go_data_scalar_str_finalize;
 	godata_klass->dup	= go_data_scalar_str_dup;
 	godata_klass->eq	= go_data_scalar_str_eq;
-	godata_klass->as_str	= go_data_scalar_str_as_str;
-	godata_klass->from_str	= go_data_scalar_str_from_str;
+	godata_klass->serialize	= go_data_scalar_str_serialize;
+	godata_klass->unserialize	= go_data_scalar_str_unserialize;
 	scalar_klass->get_value	= go_data_scalar_str_get_value;
 	scalar_klass->get_str	= go_data_scalar_str_get_str;
 }
@@ -241,12 +253,12 @@ go_data_scalar_str_init (GObject *obj)
 
 GSF_CLASS (GODataScalarStr, go_data_scalar_str,
 	   go_data_scalar_str_class_init, go_data_scalar_str_init,
-	   GO_DATA_SCALAR_TYPE)
+	   GO_TYPE_DATA_SCALAR)
 
 GOData *
 go_data_scalar_str_new (char const *str, gboolean needs_free)
 {
-	GODataScalarStr *res = g_object_new (GO_DATA_SCALAR_STR_TYPE, NULL);
+	GODataScalarStr *res = g_object_new (GO_TYPE_DATA_SCALAR_STR, NULL);
 	res->str	= str;
 	res->needs_free = needs_free;
 	return GO_DATA (res);
@@ -352,12 +364,14 @@ static char *
 go_data_vector_val_get_str (GODataVector *vec, unsigned i)
 {
 	GODataVectorVal const *val = (GODataVectorVal const *)vec;
+	GOFormat const *fmt = NULL;
+
 	g_return_val_if_fail (val != NULL && val->val != NULL && i < val->n, NULL);
-	return g_strdup_printf ("%g", val->val[i]);
+	return render_val (val->val[i], fmt);
 }
 
 static char *
-go_data_vector_val_as_str (GOData const *dat)
+go_data_vector_val_serialize (GOData const *dat, gpointer user)
 {
 	GODataVectorVal *vec = GO_DATA_VECTOR_VAL (dat);
 	GString *str;
@@ -379,7 +393,7 @@ go_data_vector_val_as_str (GOData const *dat)
 }
 
 static gboolean
-go_data_vector_val_from_str (GOData *dat, char const *str)
+go_data_vector_val_unserialize (GOData *dat, char const *str, gpointer user)
 {
 	GODataVectorVal *vec = GO_DATA_VECTOR_VAL (dat);
 	char sep, *end = (char*) str;
@@ -435,8 +449,8 @@ go_data_vector_val_class_init (GObjectClass *gobject_klass)
 	gobject_klass->finalize = go_data_vector_val_finalize;
 	godata_klass->dup	= go_data_vector_val_dup;
 	godata_klass->eq	= go_data_vector_val_eq;
-	godata_klass->as_str	= go_data_vector_val_as_str;
-	godata_klass->from_str	= go_data_vector_val_from_str;
+	godata_klass->serialize	= go_data_vector_val_serialize;
+	godata_klass->unserialize	= go_data_vector_val_unserialize;
 	vector_klass->load_len    = go_data_vector_val_load_len;
 	vector_klass->load_values = go_data_vector_val_load_values;
 	vector_klass->get_value   = go_data_vector_val_get_value;
@@ -445,12 +459,12 @@ go_data_vector_val_class_init (GObjectClass *gobject_klass)
 
 GSF_CLASS (GODataVectorVal, go_data_vector_val,
 	   go_data_vector_val_class_init, NULL,
-	   GO_DATA_VECTOR_TYPE)
+	   GO_TYPE_DATA_VECTOR)
 
 GOData *
 go_data_vector_val_new (double *val, unsigned n, GDestroyNotify notify)
 {
-	GODataVectorVal *res = g_object_new (GO_DATA_VECTOR_VAL_TYPE, NULL);
+	GODataVectorVal *res = g_object_new (GO_TYPE_DATA_VECTOR_VAL, NULL);
 	res->val = val;
 	res->n = n;
 	res->notify = notify;
@@ -527,7 +541,7 @@ go_data_vector_str_eq (GOData const *a, GOData const *b)
 }
 
 static char *
-go_data_vector_str_as_str (GOData const *dat)
+go_data_vector_str_serialize (GOData const *dat, gpointer user)
 {
 	GODataVectorStr *vec = GO_DATA_VECTOR_STR (dat);
 	GString *str;
@@ -552,7 +566,7 @@ go_data_vector_str_as_str (GOData const *dat)
 }
 
 static gboolean
-go_data_vector_str_from_str (GOData *dat, char const *str)
+go_data_vector_str_unserialize (GOData *dat, char const *str, gpointer user)
 {
 	GODataVectorStr *vec = GO_DATA_VECTOR_STR (dat);
 	char sep, *cur = (char*) str, *end, *val;
@@ -695,8 +709,8 @@ go_data_vector_str_class_init (GObjectClass *gobject_klass)
 	gobject_klass->finalize	= go_data_vector_str_finalize;
 	godata_klass->dup	= go_data_vector_str_dup;
 	godata_klass->eq	= go_data_vector_str_eq;
-	godata_klass->as_str	= go_data_vector_str_as_str;
-	godata_klass->from_str	= go_data_vector_str_from_str;
+	godata_klass->serialize	= go_data_vector_str_serialize;
+	godata_klass->unserialize	= go_data_vector_str_unserialize;
 	vector_klass->load_len    = go_data_vector_str_load_len;
 	vector_klass->load_values = go_data_vector_str_load_values;
 	vector_klass->get_value   = go_data_vector_str_get_value;
@@ -717,12 +731,12 @@ go_data_vector_str_init (GObject *obj)
 
 GSF_CLASS (GODataVectorStr, go_data_vector_str,
 	   go_data_vector_str_class_init, go_data_vector_str_init,
-	   GO_DATA_VECTOR_TYPE)
+	   GO_TYPE_DATA_VECTOR)
 
 GOData *
 go_data_vector_str_new (char const * const *str, unsigned n, GDestroyNotify notify)
 {
-	GODataVectorStr *res = g_object_new (GO_DATA_VECTOR_STR_TYPE, NULL);
+	GODataVectorStr *res = g_object_new (GO_TYPE_DATA_VECTOR_STR, NULL);
 	res->str = str;
 	res->n	 = n;
 	res->notify = notify;
@@ -874,12 +888,13 @@ static char *
 go_data_matrix_val_get_str (GODataMatrix *mat, unsigned i, unsigned j)
 {
 	GODataMatrixVal const *val = (GODataMatrixVal const *)mat;
+	GOFormat const *fmt = NULL;
 
-	return g_strdup_printf ("%g", val->val[i * val->size.columns + j]);
+	return render_val (val->val[i * val->size.columns + j], fmt);
 }
 
 static char *
-go_data_matrix_val_as_str (GOData const *dat)
+go_data_matrix_val_serialize (GOData const *dat, gpointer user)
 {
 	GODataMatrixVal *mat = GO_DATA_MATRIX_VAL (dat);
 	GString *str;
@@ -912,7 +927,7 @@ go_data_matrix_val_as_str (GOData const *dat)
 }
 
 static gboolean
-go_data_matrix_val_from_str (GOData *dat, char const *str)
+go_data_matrix_val_unserialize (GOData *dat, char const *str, gpointer user)
 {
 	GODataMatrixVal *mat = GO_DATA_MATRIX_VAL (dat);
 	char row_sep, col_sep, *end = (char*) str;
@@ -986,9 +1001,9 @@ go_data_matrix_val_class_init (GObjectClass *gobject_klass)
 	gobject_klass->finalize = go_data_matrix_val_finalize;
 	godata_klass->dup	= go_data_matrix_val_dup;
 	godata_klass->eq	= go_data_matrix_val_eq;
-	godata_klass->as_str	= go_data_matrix_val_as_str;
-	godata_klass->from_str	= go_data_matrix_val_from_str;
-	matrix_klass->load_size    = go_data_matrix_val_load_size;
+	godata_klass->serialize	= go_data_matrix_val_serialize;
+	godata_klass->unserialize = go_data_matrix_val_unserialize;
+	matrix_klass->load_size   = go_data_matrix_val_load_size;
 	matrix_klass->load_values = go_data_matrix_val_load_values;
 	matrix_klass->get_value   = go_data_matrix_val_get_value;
 	matrix_klass->get_str     = go_data_matrix_val_get_str;
@@ -996,12 +1011,12 @@ go_data_matrix_val_class_init (GObjectClass *gobject_klass)
 
 GSF_CLASS (GODataMatrixVal, go_data_matrix_val,
 	   go_data_matrix_val_class_init, NULL,
-	   GO_DATA_MATRIX_TYPE)
+	   GO_TYPE_DATA_MATRIX)
 
 GOData *
 go_data_matrix_val_new (double *val, unsigned rows, unsigned columns, GDestroyNotify   notify)
 {
-	GODataMatrixVal *res = g_object_new (GO_DATA_MATRIX_VAL_TYPE, NULL);
+	GODataMatrixVal *res = g_object_new (GO_TYPE_DATA_MATRIX_VAL, NULL);
 	res->val = val;
 	res->size.rows = rows;
 	res->size.columns = columns;
