@@ -28,7 +28,7 @@
 #include <goffice/graph/gog-chart-map-3d.h>
 #include <goffice/graph/gog-data-allocator.h>
 #include <goffice/graph/gog-renderer.h>
-#include <goffice/graph/gog-style.h>
+#include <goffice/utils/go-style.h>
 #include <goffice/graph/gog-theme.h>
 #include <goffice/math/go-math.h>
 #include <goffice/utils/go-persist.h>
@@ -37,20 +37,11 @@
 
 #ifdef GOFFICE_WITH_GTK
 #include <goffice/gtk/goffice-gtk.h>
-#include <goffice/gtk/goffice-gtk.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcelllayout.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtktogglebutton.h>
 #endif
 
 #include <glib/gi18n-lib.h>
 #include <string.h>
 
-static double gog_axis_base_get_cross_location (GogAxisBase *axis_base);
-
 static GogViewClass *gab_view_parent_klass;
 static GObjectClass *gab_parent_klass;
 
@@ -235,7 +226,7 @@ gog_axis_base_parent_changed (GogObject *child, gboolean was_set)
 	GogAxisBase *axis_base = GOG_AXIS_BASE (child);
 
 	if (was_set) {
-		if (IS_GOG_AXIS (child))
+		if (GOG_IS_AXIS (child))
 			axis_base->axis = GOG_AXIS (child);
 		else
 			axis_base->axis = GOG_AXIS (child->parent);
@@ -294,7 +285,7 @@ gog_axis_base_get_crossed_axis_type (GogAxisBase *axis_base)
 	return crossed_type;
 }
 
-static GogAxis *
+GogAxis *
 gog_axis_base_get_crossed_axis (GogAxisBase *axis_base)
 {
 	GogAxis *crossed_axis = NULL;
@@ -331,7 +322,7 @@ gog_axis_base_set_position (GogAxisBase *axis_base, GogAxisPosition position)
 	g_return_if_fail (GOG_AXIS_BASE (axis_base) != NULL);
 
 	if (position == GOG_AXIS_AUTO) {
-		if (IS_GOG_AXIS (axis_base))
+		if (GOG_IS_AXIS (axis_base))
 			axis = GOG_AXIS (axis_base);
 		else
 			axis = GOG_AXIS (gog_object_get_parent (GOG_OBJECT (axis_base)));
@@ -346,7 +337,7 @@ gog_axis_base_set_position (GogAxisBase *axis_base, GogAxisPosition position)
 			lines = gog_object_get_children (GOG_OBJECT (aptr->data), NULL);
 			lines = g_slist_prepend (lines, aptr->data);
 			for (lptr = lines; lptr != NULL; lptr = lptr->next) {
-				if (lptr->data == axis_base || !IS_GOG_AXIS_BASE (lptr->data))
+				if (lptr->data == axis_base || !GOG_IS_AXIS_BASE (lptr->data))
 					continue;
 				position = gog_axis_base_get_position (GOG_AXIS_BASE (lptr->data));
 				if (position == GOG_AXIS_AT_HIGH )
@@ -374,7 +365,7 @@ gog_axis_base_get_clamped_position (GogAxisBase *axis_base)
 {
 	GogAxisPosition axis_pos;
 
-	g_return_val_if_fail (IS_GOG_AXIS_BASE (axis_base), GOG_AXIS_AT_LOW);
+	g_return_val_if_fail (GOG_IS_AXIS_BASE (axis_base), GOG_AXIS_AT_LOW);
 
 	axis_pos = axis_base->position;
 	if (axis_pos == GOG_AXIS_CROSS) {
@@ -465,7 +456,7 @@ cb_position_toggled (GtkWidget *button, AxisBasePrefs *state)
 			lines = gog_object_get_children (GOG_OBJECT (aptr->data), NULL);
 			lines = g_slist_prepend (lines, aptr->data);
 			for (lptr = lines; lptr != NULL; lptr = lptr->next) {
-				if (lptr->data == axis_base || !IS_GOG_AXIS_BASE (lptr->data))
+				if (lptr->data == axis_base || !GOG_IS_AXIS_BASE (lptr->data))
 					continue;
 				if (position == gog_axis_base_get_position (GOG_AXIS_BASE (lptr->data))) {
 					gog_axis_base_set_position (GOG_AXIS_BASE (lptr->data),
@@ -499,7 +490,7 @@ cb_padding_changed (GtkSpinButton *spin, GObject *axis_base)
 
 static void
 gog_axis_base_populate_editor (GogObject *gobj,
-			       GogEditor *editor,
+			       GOEditor *editor,
 			       GogDataAllocator *dalloc,
 			       GOCmdContext *cc)
 {
@@ -531,7 +522,7 @@ gog_axis_base_populate_editor (GogObject *gobj,
 	if (!gog_object_is_visible (axis_base->axis))
 		return;
 
-	gog_editor_set_store_page (editor, &axis_base_pref_page);
+	go_editor_set_store_page (editor, &axis_base_pref_page);
 
 	axis_type = gog_axis_get_atype (axis_base->axis);
 	if (axis_type == GOG_AXIS_PSEUDO_3D) {
@@ -539,7 +530,7 @@ gog_axis_base_populate_editor (GogObject *gobj,
 		return;
 	}
 
-	gui = go_libglade_new ("gog-axis-prefs.glade", "axis_base_pref_box", GETTEXT_PACKAGE, cc);
+	gui = go_glade_new ("gog-axis-prefs.glade", "axis_base_pref_box", GETTEXT_PACKAGE, cc);
 	if (gui == NULL) {
 		(GOG_OBJECT_CLASS(gab_parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
 		return;
@@ -651,7 +642,7 @@ gog_axis_base_populate_editor (GogObject *gobj,
 		gtk_widget_hide (w);
 	}
 
-	gog_editor_add_page (editor,
+	go_editor_add_page (editor,
 			     glade_xml_get_widget (gui, "axis_base_pref_box"),
 			     _("Layout"));
 
@@ -660,9 +651,9 @@ gog_axis_base_populate_editor (GogObject *gobj,
 #endif
 
 static void
-gog_axis_base_init_style (GogStyledObject *gso, GogStyle *style)
+gog_axis_base_init_style (GogStyledObject *gso, GOStyle *style)
 {
-	style->interesting_fields = GOG_STYLE_LINE | GOG_STYLE_FONT;
+	style->interesting_fields = GO_STYLE_LINE | GO_STYLE_FONT;
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
 		style, GOG_OBJECT (gso), 0, FALSE);
 }
@@ -772,7 +763,7 @@ gog_axis_base_init (GogAxisBase *gab)
 	gab->minor.size_pts = 2;
 }
 
-static double
+double
 gog_axis_base_get_cross_location (GogAxisBase *axis_base)
 {
 	GOData *data;
@@ -780,8 +771,8 @@ gog_axis_base_get_cross_location (GogAxisBase *axis_base)
 	g_return_val_if_fail (GOG_AXIS_BASE (axis_base) != NULL, 0.);
 
 	data = axis_base->cross_location.data;
-	if (data != NULL && IS_GO_DATA_SCALAR (data))
-		return go_data_scalar_get_value (GO_DATA_SCALAR (data));
+	if (GO_IS_DATA (data))
+		return go_data_get_scalar_value (data);
 
 	return 0.;
 }
@@ -803,7 +794,7 @@ gog_axis_base_get_padding (GogAxisBase *axis_base)
 
 GSF_CLASS_ABSTRACT (GogAxisBase, gog_axis_base,
 		    gog_axis_base_class_init, gog_axis_base_init,
-		    GOG_STYLED_OBJECT_TYPE);
+		    GOG_TYPE_STYLED_OBJECT);
 
 /************************************************************************/
 static gboolean gog_axis_base_view_point (GogView *view, double x, double y);
@@ -1002,7 +993,7 @@ axis_line_get_bbox (GogAxisBase *axis_base, GogRenderer *renderer,
 	GogAxisMap *map = NULL;
 	GogAxisTick *ticks;
 	GOGeometryAABR total_bbox, bbox;
-	GogStyle *style = axis_base->base.style;
+	GOStyle *style = axis_base->base.style;
 	GOGeometryAABR txt_aabr;
 	GOGeometryOBR txt_obr;
 	GOGeometryOBR *obrs = NULL;
@@ -1021,7 +1012,7 @@ axis_line_get_bbox (GogAxisBase *axis_base, GogRenderer *renderer,
 	cos_alpha = side == GO_SIDE_LEFT ? - sin (axis_angle) : + sin (axis_angle);
 	sin_alpha = side == GO_SIDE_LEFT ? + cos (axis_angle) : - cos (axis_angle);
 
-	is_line_visible = gog_style_is_line_visible (style);
+	is_line_visible = go_style_is_line_visible (style);
 	line_width = gog_renderer_line_size (renderer, style->line.width) / 2;
 
 	minor_tick_len = gog_renderer_pt2r (renderer, axis_base->minor.size_pts);
@@ -1115,7 +1106,7 @@ axis_line_render (GogAxisBase *axis_base,
 {
 	GogAxisMap *map = NULL;
 	GogAxisTick *ticks;
-	GogStyle *style = axis_base->base.style;
+	GOStyle *style = axis_base->base.style;
 	GOGeometryOBR zero_obr;
 	GOGeometryOBR *obrs = NULL;
 	GOGeometrySide label_anchor = GO_SIDE_AUTO;
@@ -1145,7 +1136,7 @@ axis_line_render (GogAxisBase *axis_base,
 	axis_base_view->x_stop = x + w;
 	axis_base_view->y_stop = y + h;
 
-	is_line_visible = gog_style_is_line_visible (style);
+	is_line_visible = go_style_is_line_visible (style);
 	line_width = gog_renderer_line_size (renderer, style->line.width) / 2;
 
 	if (is_line_visible)
@@ -1334,7 +1325,7 @@ axis_circle_get_bbox (GogAxisBase *axis_base, GogRenderer *renderer,
 	gog_renderer_get_text_OBR (renderer, "0", TRUE, &txt_obr);
 	label_padding = txt_obr.w;
 
-	draw_ticks = gog_style_is_line_visible (axis_base->base.style) &&
+	draw_ticks = go_style_is_line_visible (axis_base->base.style) &&
 		(axis_base->major.tick_out || axis_base->minor.tick_out);
 
 	map = gog_chart_map_get_axis_map (c_map, 1);
@@ -1406,7 +1397,7 @@ axis_circle_render (GogAxisBase *axis_base, GogRenderer *renderer,
 		go_path_arc (path, parms->cx, parms->cy, parms->rx, parms->ry,
 			     -parms->th1, -parms->th0);
 
-	is_line_visible = gog_style_is_line_visible (axis_base->base.style);
+	is_line_visible = go_style_is_line_visible (axis_base->base.style);
 	draw_major = axis_base->major.tick_in || axis_base->major.tick_out;
 	draw_minor = axis_base->minor.tick_in || axis_base->minor.tick_out;
 
@@ -2061,7 +2052,7 @@ gog_axis_base_view_point (GogView *view, double x, double y)
 		return FALSE;
 
 	/* FIXME: not nice */
-	if (IS_GOG_AXIS (view->model))
+	if (GOG_IS_AXIS (view->model))
 		plot_area = gog_chart_view_get_plot_area (view->parent);
 	else
 		plot_area = gog_chart_view_get_plot_area (view->parent->parent);
@@ -2101,7 +2092,7 @@ gog_axis_base_view_padding_request (GogView *view, GogViewAllocation const *bbox
 {
 	GogAxisSet axis_set;
 	GogAxisBase *axis_base = GOG_AXIS_BASE (view->model);
-	GogStyle *style = axis_base->base.style;
+	GOStyle *style = axis_base->base.style;
 
 	if (gog_axis_get_atype (axis_base->axis) >= GOG_AXIS_VIRTUAL)
 		return;
@@ -2139,7 +2130,7 @@ gog_axis_base_view_render (GogView *view, GogViewAllocation const *bbox)
 {
 	GogAxisSet axis_set;
 	GogAxisBase *axis_base = GOG_AXIS_BASE (view->model);
-	GogStyle *style = axis_base->base.style;
+	GOStyle *style = axis_base->base.style;
 	GogViewAllocation const *plot_area;
 
 	if (gog_axis_get_atype (axis_base->axis) >= GOG_AXIS_VIRTUAL)
@@ -2149,7 +2140,7 @@ gog_axis_base_view_render (GogView *view, GogViewAllocation const *bbox)
 		return;
 
 	/* FIXME: not nice */
-	if (IS_GOG_AXIS (view->model))
+	if (GOG_IS_AXIS (view->model))
 		plot_area = gog_chart_view_get_plot_area (view->parent);
 	else
 		plot_area = gog_chart_view_get_plot_area (view->parent->parent);
@@ -2195,7 +2186,7 @@ gog_axis_base_view_label_position_request (GogView *view,
 {
 	GogAxisSet axis_set;
 	GogAxisBase *axis_base = GOG_AXIS_BASE (view->model);
-	GogStyle *style = axis_base->base.style;
+	GOStyle *style = axis_base->base.style;
 	GogViewPadding padding = {0};
 
 	if (gog_axis_get_atype (axis_base->axis) >= GOG_AXIS_VIRTUAL)
@@ -2239,7 +2230,7 @@ gog_axis_base_view_class_init (GogAxisBaseViewClass *gview_klass)
 
 GSF_CLASS (GogAxisBaseView, gog_axis_base_view,
 	   gog_axis_base_view_class_init, NULL,
-	   GOG_VIEW_TYPE)
+	   GOG_TYPE_VIEW)
 
 /*****************************************************************************/
 /*****************************************************************************/
@@ -2292,5 +2283,5 @@ gog_axis_line_dataset_init (GogDatasetClass *iface)
 
 GSF_CLASS_FULL (GogAxisLine, gog_axis_line,
 		NULL, NULL, gog_axis_line_class_init, NULL,
-		NULL /*init*/, GOG_AXIS_BASE_TYPE, 0,
-		GSF_INTERFACE (gog_axis_line_dataset_init, GOG_DATASET_TYPE))
+		NULL /*init*/, GOG_TYPE_AXIS_BASE, 0,
+		GSF_INTERFACE (gog_axis_line_dataset_init, GOG_TYPE_DATASET))
