@@ -25,7 +25,6 @@
 #include <goffice/graph/gog-series-impl.h>
 #include <goffice/graph/gog-chart.h>
 #include <goffice/graph/gog-axis.h>
-#include <goffice/graph/gog-style.h>
 #include <goffice/graph/gog-theme.h>
 #include <goffice/graph/gog-graph.h>
 #include <goffice/graph/gog-object-xml.h>
@@ -33,6 +32,8 @@
 #include <goffice/data/go-data.h>
 #include <goffice/math/go-math.h>
 #include <goffice/utils/go-persist.h>
+#include <goffice/utils/go-style.h>
+#include <goffice/utils/go-styled-object.h>
 #include <glib/gi18n-lib.h>
 
 #ifdef GOFFICE_WITH_GTK
@@ -42,7 +43,7 @@
 #include <gsf/gsf-impl-utils.h>
 #include <string.h>
 
-#define GOG_PLOT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_PLOT_TYPE, GogPlotClass))
+#define GOG_PLOT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_TYPE_PLOT, GogPlotClass))
 
 enum {
 	PLOT_PROP_0,
@@ -87,7 +88,7 @@ role_series_allocate (GogObject *plot)
 	GType type = klass->series_type;
 
 	if (type == 0)
-		type = GOG_SERIES_TYPE;
+		type = GOG_TYPE_SERIES;
 	return g_object_new (type, NULL);
 }
 
@@ -251,7 +252,7 @@ cb_update_editor (GogObject *gobj, PlotPrefState *state)
 
 static void
 gog_plot_populate_editor (GogObject *obj,
-			  GogEditor *editor,
+			  GOEditor *editor,
 			  G_GNUC_UNUSED GogDataAllocator *dalloc,
 			  GOCmdContext *cc)
 {
@@ -282,7 +283,7 @@ gog_plot_populate_editor (GogObject *obj,
 	gboolean is_plot_area_manual;
 
 	g_return_if_fail (chart != NULL);
-	gui = go_libglade_new ("gog-plot-prefs.glade", "gog_plot_prefs", GETTEXT_PACKAGE, cc);
+	gui = go_glade_new ("gog-plot-prefs.glade", "gog_plot_prefs", GETTEXT_PACKAGE, cc);
 	g_return_if_fail (gui != NULL);
 
 	state = g_new  (PlotPrefState, 1);
@@ -342,7 +343,7 @@ gog_plot_populate_editor (GogObject *obj,
 			gtk_table_set_row_spacings (GTK_TABLE (table), 6);
 			gtk_container_set_border_width (GTK_CONTAINER (table), 12);
 			gtk_widget_show_all (table);
-			gog_editor_add_page (editor, table, _("Axes"));
+			go_editor_add_page (editor, table, _("Axes"));
 		}
 		else
 			g_object_unref (G_OBJECT (table));
@@ -391,7 +392,7 @@ gog_plot_populate_editor (GogObject *obj,
 	w = glade_xml_get_widget (gui, "gog_plot_prefs");
 	g_object_set_data_full (G_OBJECT (w), "state", state, 
 				(GDestroyNotify) plot_pref_state_free);  
-	gog_editor_add_page (editor, w, _("Plot area"));
+	go_editor_add_page (editor, w, _("Plot area"));
 
 	state->update_editor_handler = g_signal_connect (G_OBJECT (plot), 
 							 "update-editor", 
@@ -481,7 +482,7 @@ gog_plot_children_reordered (GogObject *obj)
 	GogPlot *plot = GOG_PLOT (obj);
 
 	for (ptr = obj->children; ptr != NULL ; ptr = ptr->next)
-		if (IS_GOG_SERIES (ptr->data))
+		if (GOG_IS_SERIES (ptr->data))
 			accum = g_slist_prepend (accum, ptr->data);
 	g_slist_free (plot->series);
 	plot->series = g_slist_reverse (accum);
@@ -570,7 +571,7 @@ gog_plot_init (GogPlot *plot, GogPlotClass const *derived_plot_klass)
 
 GSF_CLASS_ABSTRACT (GogPlot, gog_plot,
 		    gog_plot_class_init, gog_plot_init,
-		    GOG_OBJECT_TYPE)
+		    GOG_TYPE_OBJECT)
 
 GogPlot *
 gog_plot_new_by_type (GogPlotType const *type)
@@ -601,7 +602,7 @@ gog_plot_new_series (GogPlot *plot)
 {
 	GogObject *res;
 
-	g_return_val_if_fail (IS_GOG_PLOT (plot), NULL);
+	g_return_val_if_fail (GOG_IS_PLOT (plot), NULL);
 
 	res = gog_object_add_by_name (GOG_OBJECT (plot), "Series", NULL);
 	return res ? GOG_SERIES (res) : NULL;
@@ -609,7 +610,7 @@ gog_plot_new_series (GogPlot *plot)
 GogPlotDesc const *
 gog_plot_description (GogPlot const *plot)
 {
-	g_return_val_if_fail (IS_GOG_PLOT (plot), NULL);
+	g_return_val_if_fail (GOG_IS_PLOT (plot), NULL);
 	return &plot->desc;
 }
 
@@ -623,7 +624,7 @@ gog_plot_get_chart (GogPlot const *plot)
 void
 gog_plot_request_cardinality_update (GogPlot *plot)
 {
-	g_return_if_fail (IS_GOG_PLOT (plot));
+	g_return_if_fail (GOG_IS_PLOT (plot));
 
 	if (plot->cardinality_valid) {
 		GogChart *chart = gog_plot_get_chart (plot);
@@ -649,7 +650,7 @@ gog_plot_update_cardinality (GogPlot *plot, int index_num)
 	gboolean   is_valid;
 	unsigned   size = 0, no_legend = 0, i;
 
-	g_return_if_fail (IS_GOG_PLOT (plot));
+	g_return_if_fail (GOG_IS_PLOT (plot));
 
 	plot->cardinality_valid = TRUE;
 	plot->index_num = i = index_num;
@@ -687,7 +688,7 @@ gog_plot_update_cardinality (GogPlot *plot, int index_num)
 void
 gog_plot_get_cardinality (GogPlot *plot, unsigned *full, unsigned *visible)
 {
-	g_return_if_fail (IS_GOG_PLOT (plot));
+	g_return_if_fail (GOG_IS_PLOT (plot));
 
 	if (!plot->cardinality_valid)
 		g_warning ("[GogPlot::get_cardinality] Invalid cardinality");
@@ -711,15 +712,15 @@ gog_plot_foreach_elem (GogPlot *plot, gboolean only_visible,
 {
 	GSList *ptr;
 	GogSeries const *series;
-	GogStyle *style, *tmp_style;
-	GODataVector *labels;
+	GOStyle *style, *tmp_style;
+	GOData *labels;
 	unsigned i, n, num_labels = 0;
 	char *label = NULL;
 	GogTheme *theme = gog_object_get_theme (GOG_OBJECT (plot));
 	GogPlotClass *klass = GOG_PLOT_GET_CLASS (plot);
 	GList *overrides;
 
-	g_return_if_fail (IS_GOG_PLOT (plot));
+	g_return_if_fail (GOG_IS_PLOT (plot));
 	if (!plot->cardinality_valid)
 		gog_plot_get_cardinality (plot, NULL, NULL);
 
@@ -742,7 +743,7 @@ gog_plot_foreach_elem (GogPlot *plot, gboolean only_visible,
 
 		for (; ptr != NULL ; ptr = ptr->next)
 			if (!only_visible || gog_series_has_legend (ptr->data)) {
-				func (i, gog_styled_object_get_style (ptr->data),
+				func (i, go_styled_object_get_style (ptr->data),
 				      gog_object_get_name (ptr->data), data);
 				i++;
 			}
@@ -755,10 +756,10 @@ gog_plot_foreach_elem (GogPlot *plot, gboolean only_visible,
 	series = ptr->data; /* start with the first */
 	labels = NULL;
 	if (series->values[0].data != NULL) {
-		labels = GO_DATA_VECTOR (series->values[0].data);
-		num_labels = go_data_vector_get_len (labels);
+		labels = series->values[0].data;
+		num_labels = go_data_get_vector_size (labels);
 	}
-	style = gog_style_dup (series->base.style);
+	style = go_style_dup (series->base.style);
 	n = only_visible ? plot->visible_cardinality : plot->full_cardinality;
 	for (overrides = series->overrides, i = 0; i < n ; i++) {
 		if (overrides != NULL &&
@@ -771,8 +772,7 @@ gog_plot_foreach_elem (GogPlot *plot, gboolean only_visible,
 		gog_theme_fillin_style (theme, tmp_style, GOG_OBJECT (series),
 			plot->index_num + i, FALSE);
 		if (labels != NULL)
- 			label = (i < num_labels)
- 				? go_data_vector_get_str (labels, i) : g_strdup ("");
+			label = (i < num_labels) ? go_data_get_vector_string (labels, i) : g_strdup ("");
 		else
 			label = NULL;
 		if (label == NULL)
@@ -792,7 +792,7 @@ gog_plot_foreach_elem (GogPlot *plot, gboolean only_visible,
 GSList const *
 gog_plot_get_series (GogPlot const *plot)
 {
-	g_return_val_if_fail (IS_GOG_PLOT (plot), NULL);
+	g_return_val_if_fail (GOG_IS_PLOT (plot), NULL);
 	return plot->series;
 }
 
@@ -804,7 +804,7 @@ gog_plot_get_series (GogPlot const *plot)
  *
  * Queries @plot for its axis preferences for @axis and stores the results in
  * @bounds.  All elements of @bounds are initialized to sane values before the
- * query _ACCEPT_ ::fmt.  The caller is responsible for initializing it.  This
+ * query _EXCEPT_ ::fmt.  The caller is responsible for initializing it.  This
  * is done so that once on plot has selected a format the others need not do
  * the lookup too if so desired.
  *
@@ -827,6 +827,8 @@ gog_plot_get_axis_bounds (GogPlot *plot, GogAxisType axis,
 	bounds->logical.minima = go_nan;
 	bounds->is_discrete = FALSE;
 	bounds->center_on_ticks = TRUE;
+	bounds->date_conv = NULL;
+
 	if (klass->axis_get_bounds == NULL)
 		return NULL;
 	return (klass->axis_get_bounds) (plot, axis, bounds);
@@ -873,8 +875,8 @@ void
 gog_plot_set_axis (GogPlot *plot, GogAxis *axis)
 {
 	GogAxisType type;
-	g_return_if_fail (IS_GOG_PLOT (plot));
-	g_return_if_fail (IS_GOG_AXIS (axis));
+	g_return_if_fail (GOG_IS_PLOT (plot));
+	g_return_if_fail (GOG_IS_AXIS (axis));
 
 	type = gog_axis_get_atype (axis);
 	g_return_if_fail (type != GOG_AXIS_UNKNOWN);
@@ -899,7 +901,7 @@ gog_plot_set_axis_by_id (GogPlot *plot, GogAxisType type, unsigned id)
 	if (id == 0)
 		return FALSE;
 
-	g_return_val_if_fail (IS_GOG_PLOT (plot), FALSE);
+	g_return_val_if_fail (GOG_IS_PLOT (plot), FALSE);
 	g_return_val_if_fail (GOG_OBJECT (plot)->parent != NULL, FALSE);
 
 	chart = gog_plot_get_chart (plot);
@@ -960,7 +962,7 @@ gog_plot_axis_clear (GogPlot *plot, GogAxisSet filter)
 {
 	GogAxisType type;
 
-	g_return_if_fail (IS_GOG_PLOT (plot));
+	g_return_if_fail (GOG_IS_PLOT (plot));
 
 	for (type = 0 ; type < GOG_AXIS_TYPES ; type++)
 		if (plot->axis[type] != NULL && ((1 << type) & filter)) {
@@ -980,7 +982,7 @@ gog_plot_get_axis_id (GogPlot const *plot, GogAxisType type)
 GogAxis	*
 gog_plot_get_axis (GogPlot const *plot, GogAxisType type)
 {
-	g_return_val_if_fail (IS_GOG_PLOT (plot), NULL);
+	g_return_val_if_fail (GOG_IS_PLOT (plot), NULL);
 	g_return_val_if_fail (type < GOG_AXIS_TYPES, NULL);
 	g_return_val_if_fail (GOG_AXIS_UNKNOWN < type, NULL);
 	return plot->axis[type];
@@ -990,7 +992,7 @@ void
 gog_plot_update_3d (GogPlot *plot)
 {
 	GogPlotClass *klass = GOG_PLOT_GET_CLASS (plot);
-	g_return_if_fail (IS_GOG_PLOT (plot));
+	g_return_if_fail (GOG_IS_PLOT (plot));
 
 	if (klass->update_3d)
 		klass->update_3d (plot);
@@ -1002,10 +1004,10 @@ gog_plot_guru_helper_add_grid_line (GogPlot *plot, gboolean major)
 	GogAxisType type;
 
 	for (type = 0; type < GOG_AXIS_TYPES; type++) {
-		if (((type & (GOG_AXIS_X | 
-			    GOG_AXIS_Y | 
-			    GOG_AXIS_CIRCULAR | 
-			    GOG_AXIS_RADIAL)) != 0) &&
+		if ((((type == GOG_AXIS_X) | 
+		      (type == GOG_AXIS_Y) | 
+		      (type == GOG_AXIS_CIRCULAR) | 
+		      (type == GOG_AXIS_RADIAL))) &&
 		    plot->axis[type] != NULL &&
 		    gog_axis_get_grid_line (plot->axis[type], major) == NULL)
 		{
@@ -1023,7 +1025,7 @@ gog_plot_guru_helper (GogPlot *plot)
 	char *hint;
 	unsigned i;
 
-	g_return_if_fail (IS_GOG_PLOT (plot));
+	g_return_if_fail (GOG_IS_PLOT (plot));
 	klass = GOG_PLOT_GET_CLASS (plot);
 
 	if (plot->guru_hints == NULL)
@@ -1219,4 +1221,4 @@ gog_plot_view_class_init (GogPlotViewClass *pview_klass)
 
 GSF_CLASS_ABSTRACT (GogPlotView, gog_plot_view,
 		    gog_plot_view_class_init, NULL,
-		    GOG_VIEW_TYPE)
+		    GOG_TYPE_VIEW)
