@@ -35,16 +35,18 @@ typedef struct {
 	gboolean is_discrete;
 	gboolean center_on_ticks;
 	GOFormat *fmt;
+
+	/* Note: apart from NULL, don't expect anything here yet.  */
+	const GODateConventions *date_conv;
 } GogPlotBoundInfo;
 
-#define GOG_PLOT_TYPE	(gog_plot_get_type ())
-#define GOG_PLOT(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_PLOT_TYPE, GogPlot))
-#define IS_GOG_PLOT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_PLOT_TYPE))
+#define GOG_TYPE_PLOT	(gog_plot_get_type ())
+#define GOG_PLOT(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_PLOT, GogPlot))
+#define GOG_IS_PLOT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_PLOT))
 
 GType	  gog_plot_get_type (void);
 GogPlot  *gog_plot_new_by_type	(GogPlotType const *type);
 GogPlot  *gog_plot_new_by_name	(char const *id);
-gboolean  gog_plot_make_similar	(GogPlot *dst, GogPlot const *src);
 
 void	  gog_plot_request_cardinality_update 	(GogPlot *plot);
 void 	  gog_plot_update_cardinality 		(GogPlot *plot, int index_num);
@@ -66,10 +68,12 @@ gboolean   gog_plot_axis_set_is_valid	(GogPlot const *plot, GogAxisSet type);
 gboolean   gog_plot_axis_set_assign	(GogPlot *plot, GogAxisSet type);
 void	   gog_plot_axis_clear		(GogPlot *plot, GogAxisSet filter);
 GogAxis	  *gog_plot_get_axis		(GogPlot const *plot, GogAxisType type);
+void	   gog_plot_set_axis		(GogPlot *plot, GogAxis *axis);
 
 void 	   gog_plot_update_3d 		(GogPlot *plot);
 
 void	   gog_plot_guru_helper		(GogPlot *plot);
+void	   gog_plot_clear_series	(GogPlot *plot);
 
 G_END_DECLS
 
