@@ -103,8 +103,10 @@ go_gtk_dialog_add_button (GtkDialog *dialog, char const* text, char const* stock
 
 /**
  * go_glade_new :
- * @gcc : #GOCmdContext
  * @gladefile : the name of the file load
+ * @root : Name of the root object
+ * @domain : The translation domain
+ * @gcc : #GOCmdContext
  *
  * Simple utility to open glade files
  *
@@ -142,7 +144,7 @@ go_glade_new (char const *gladefile, char const *root,
  * @gui : #GladeXML
  * @instance_name : widget name
  * @detailed_signal : signal name
- * @c_handle : #GCallback
+ * @c_handler : #GCallback
  * @data : arbitrary
  *
  * Convenience wrapper around g_signal_connect for glade.
@@ -164,11 +166,11 @@ go_glade_signal_connect	(GladeXML	*gui,
 }
 
 /**
- * go_glade_signal_connect :
+ * go_glade_signal_connect_swapped :
  * @gui : #GladeXML
  * @instance_name : widget name
  * @detailed_signal : signal name
- * @c_handle : #GCallback
+ * @c_handler : #GCallback
  * @data : arbitary
  *
  * Convenience wrapper around g_signal_connect_swapped for glade.
@@ -189,6 +191,49 @@ go_glade_signal_connect_swapped (GladeXML	*gui,
 	return g_signal_connect_swapped (w, detailed_signal, c_handler, data);
 }
 
+/**
+ * go_xml_builder_new :
+ * @uifile : the name of the file load
+ * @domain : the translation domain
+ * @gcc : #GOCmdContext
+ *
+ * Simple utility to open ui files
+ *
+ * Returns: a new #GtkBuilder or NULL
+ **/
+GtkBuilder *
+go_xml_builder_new (char const *uifile,
+		    char const *domain, GOCmdContext *gcc)
+{
+	GtkBuilder *gui;
+	char *f;
+	GError *error = NULL;
+
+	g_return_val_if_fail (uifile != NULL, NULL);
+
+	if (!g_path_is_absolute (uifile))
+		f = g_build_filename (go_sys_data_dir (), "glade", uifile, NULL);
+	else
+		f = g_strdup (uifile);
+
+	gui = gtk_builder_new ();
+	gtk_builder_set_translation_domain (gui, domain);
+	gtk_builder_add_from_file (gui, f, &error);
+	if (gui == NULL && gcc != NULL) {
+		char *msg;
+		if (error) {
+			msg = g_strdup (error->message);
+			g_error_free (error);
+		} else
+			msg = g_strdup_printf (_("Unable to open file '%s'"), f);
+		go_cmd_context_error_system (gcc, msg);
+		g_free (msg);
+	}
+	g_free (f);
+
+	return gui;
+}
+
 /*
  * A variant of gtk_window_activate_default that does not end up reactivating
  * the widget that [Enter] was pressed in.
@@ -614,7 +659,7 @@ cb_format_combo_changed (GtkComboBox *combo, GtkWidget *expander)
  **/
 char *
 go_gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
-			 GOImageFormat *ret_format, double *resolution)
+			    GOImageFormat *ret_format, double *resolution)
 {
 	GOImageFormat format;
 	GOImageFormatInfo const *format_info;
@@ -642,7 +687,7 @@ go_gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
 
 	g_object_set (G_OBJECT (fsel), "title", _("Save as"), NULL);
 
-	gui = go_libglade_new ("go-image-save-dialog-extra.glade", 
+	gui = go_glade_new ("go-image-save-dialog-extra.glade", 
 			       "image_save_dialog_extra", 
 			       GETTEXT_PACKAGE, NULL);
 	if (gui != NULL) {
@@ -730,7 +775,7 @@ go_gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
 		goto loop;
 	}
  out:
-	if (uri != NULL) {
+	if (uri != NULL && ret_format != NULL) {
 		g_free (state->uri);
 		state->uri = g_strdup (uri);
 		state->format = *ret_format;
@@ -779,18 +824,37 @@ typedef struct {
 	char const *link;
 } CBHelpPaths;
 
-#ifdef GOFFICE_WITH_GNOME
-#include <libgnome/gnome-help.h>
-#elif defined(G_OS_WIN32)
+#ifdef G_OS_WIN32
 #include <windows.h>
-#include <htmlhelp.h>
+
+typedef HWND (* WINAPI HtmlHelpA_t) (HWND hwndCaller,
+				     LPCSTR pszFile,
+				     UINT uCommand,
+				     DWORD_PTR dwData);
+#define HH_HELP_CONTEXT 0x000F
+
+static HtmlHelpA_t
+html_help (void)
+{
+	HMODULE hhctrl;
+	static HtmlHelpA_t result = NULL;
+	static gboolean beenhere = FALSE;
+
+	if (!beenhere) {
+		hhctrl = LoadLibrary ("hhctrl.ocx");
+		if (hhctrl != NULL)
+			result = (HtmlHelpA_t) GetProcAddress (hhctrl, "HtmlHelpA");
+		beenhere = TRUE;
+	}
+
+	return result;
+}
+
 #endif
 static void
 go_help_display (CBHelpPaths const *paths)
 {
-#ifdef GOFFICE_WITH_GNOME
-	gnome_help_display (paths->app, paths->link, NULL);
-#elif defined(G_OS_WIN32)
+#if defined(G_OS_WIN32)
 	static GHashTable* context_help_map = NULL;
 	guint id;
 
@@ -839,13 +903,16 @@ go_help_display (CBHelpPaths const *paths)
 		gchar *path = g_build_filename (paths->data_dir, "doc", "C", chmfile, NULL);
 
 		g_free (chmfile);
-		if (!HtmlHelp (GetDesktopWindow (), path, HH_HELP_CONTEXT, id))
-			go_gtk_notice_dialog (NULL, GTK_MESSAGE_ERROR, "Failed to spawn HtmlHelp");
+		if (html_help () == NULL ||
+		    !(html_help ()) (GetDesktopWindow (), path, HH_HELP_CONTEXT, id))
+			go_gtk_notice_dialog (NULL, GTK_MESSAGE_ERROR, "Failed to load HtmlHelp");
 		g_free (path);
 	}
 #else
-	go_gtk_notice_dialog (NULL, GTK_MESSAGE_ERROR,
-			      "TODO : launch help browser for %s", paths->link);
+	char *uri = g_strconcat ("ghelp:", paths->app, "#", paths->link, NULL);
+	go_url_show (uri);
+	g_free (uri);
+	return;
 #endif
 }
 
@@ -920,6 +987,8 @@ go_gtk_url_is_writeable (GtkWindow *parent, char const *uri,
 			_("A file called <i>%s</i> already exists in %s.\n\n"
 			  "Do you want to save over it?"),
 			basename, dirname);
+		/* gcc complains over this, but the format seems right and
+		   is not supposed to be constant.  Using "%s" is wrong.  */
 		GtkWidget *dialog = gtk_message_dialog_new_with_markup (parent,
 			 GTK_DIALOG_DESTROY_WITH_PARENT,
 			 GTK_MESSAGE_WARNING,
@@ -1241,3 +1310,25 @@ go_menu_position_below (GtkMenu  *menu,
 
 	*push_in = FALSE;
 }
+
+/**
+ * go_gtk_url_show:
+ * @url: the url to show
+ * @screen: screen to show the uri on or %NULL for the default screen
+ *
+ * This function is a simple convenience wrapper for #gtk_show_uri.
+ *
+ * Returns: %NULL on sucess, or a newly allocated #GError if something
+ * went wrong.
+ **/
+GError *
+go_gtk_url_show (gchar const *url, GdkScreen *screen)
+{
+#if defined(HAVE_GTK_SHOW_URI)
+	GError *error = NULL;
+	gtk_show_uri (screen, url, GDK_CURRENT_TIME, &error);
+	return error;
+#else
+	return go_url_show (url);
+#endif
+}
