@@ -19,11 +19,8 @@
 #ifndef _GOFFICE_GTK_H_
 #define _GOFFICE_GTK_H_
 
-#include <gtk/gtkmessagedialog.h>
-#include <gtk/gtktoolitem.h>
-#include <gtk/gtkmenu.h>
+#include <gtk/gtk.h>
 #include <glade/glade-xml.h>
-#include <gtk/gtkfilechooser.h>
 #include <goffice/app/goffice-app.h>
 #include <goffice/utils/go-image.h>
 
@@ -31,10 +28,10 @@ G_BEGIN_DECLS
 
 void	   go_gtk_editable_enters (GtkWindow *window, GtkWidget *w);
 
-/* go_libglade_new deprecated in 0.4.3, will be removed in 0.5.x */
-#define go_libglade_new	go_glade_new
-GladeXML  *go_glade_new		   	   (char const *gladefile, char const *root,
-					    char const *domain, GOCmdContext *cc);
+GladeXML  *go_glade_new		   	   (char const *gladefile,
+					    char const *root,
+					    char const *domain,
+					    GOCmdContext *gcc);
 gulong	   go_glade_signal_connect	   (GladeXML *gui,
 					    gchar const *instance_name,
 					    gchar const *detailed_signal,
@@ -46,6 +43,10 @@ gulong	   go_glade_signal_connect_swapped (GladeXML *gui,
 					    GCallback	 c_handler,
 					    gpointer	 data);
 
+GtkBuilder *go_xml_builder_new (char const *uifile,
+						char const *domain, GOCmdContext *gcc);
+
+
 int	   go_pango_measure_string	(PangoContext *context,
 					 PangoFontDescription const *font_desc,
 					 char const *str);
@@ -69,8 +70,10 @@ void	   go_gtk_help_button_init	(GtkWidget *w, char const *data_dir,
 void       go_gtk_nonmodal_dialog	(GtkWindow *toplevel, GtkWindow *dialog);
 gboolean   go_gtk_file_sel_dialog	(GtkWindow *toplevel, GtkWidget *w);
 char	  *go_gtk_select_image		(GtkWindow *toplevel, const char *initial);
-char      *go_gui_get_image_save_info 	(GtkWindow *toplevel, GSList *supported_formats,
-					 GOImageFormat *ret_format, double *dpi);
+char      *go_gui_get_image_save_info 	(GtkWindow *toplevel,
+					 GSList *supported_formats,
+					 GOImageFormat *ret_format,
+					 double *resolution);
 
 gboolean   go_gtk_url_is_writeable	(GtkWindow *parent, char const *uri,
 					 gboolean overwrite_by_default);
@@ -85,6 +88,8 @@ void       go_tool_item_set_tooltip_text (GtkToolItem *item, const gchar *tip);
 void 	   go_menu_position_below 		(GtkMenu *menu, gint *x, gint *y,
 						 gint *push_in, gpointer user_data);
 
+GError	  *go_gtk_url_show (gchar const *url, GdkScreen *screen);
+
 G_END_DECLS
 
 #endif /* _GOFFICE_GTK_H_ */
