@@ -31,7 +31,7 @@
 #include <goffice/graph/gog-view.h>
 #include <goffice/graph/gog-renderer.h>
 #include <goffice/graph/gog-axis.h>
-#include <goffice/graph/gog-style.h>
+#include <goffice/utils/go-style.h>
 #include <goffice/data/go-data.h>
 #include <goffice/math/go-math.h>
 #include <goffice/utils/go-color.h>
@@ -189,12 +189,10 @@ gog_plot1_5d_update (GogObject *obj)
 			if (gog_error_bar_is_visible (series->errors))
 				gog_error_bar_get_minmax (series->errors, &minima, &maxima);
 			else
-				go_data_vector_get_minmax (GO_DATA_VECTOR (
-					series->base.values[1].data), &minima, &maxima);
+				go_data_get_bounds (series->base.values[1].data, &minima, &maxima);
 			if (series->base.plot->desc.series.num_dim == 3) {
 				double tmp_min, tmp_max;
-				go_data_vector_get_minmax (GO_DATA_VECTOR (
-					series->base.values[2].data), &tmp_min, &tmp_max);
+				go_data_get_bounds (series->base.values[2].data, &tmp_min, &tmp_max);
 				if (minima > tmp_min )
 					minima = tmp_min;
 				if (maxima < tmp_max)
@@ -238,13 +236,11 @@ gog_plot1_5d_update (GogObject *obj)
 			if (!gog_series_is_valid (GOG_SERIES (series))) {
 				continue;
 			}
-			vals[i] = go_data_vector_get_values (
-				GO_DATA_VECTOR (series->base.values[1].data));
+			vals[i] = go_data_get_values (series->base.values[1].data);
 			g_object_get (G_OBJECT (series), "errors", errors + i, NULL);
 			if (errors[i])
 				g_object_unref (errors[i]);
-			lengths[i] = go_data_vector_get_len (
-				GO_DATA_VECTOR (series->base.values[1].data));
+			lengths[i] = go_data_get_vector_size (series->base.values[1].data);
 
 			i++;
 		}
@@ -378,7 +374,7 @@ gog_plot1_5d_init (GogPlot1_5d *plot)
 
 GSF_DYNAMIC_CLASS_ABSTRACT (GogPlot1_5d, gog_plot1_5d,
 	gog_plot1_5d_class_init, gog_plot1_5d_init,
-	GOG_PLOT_TYPE)
+	GOG_TYPE_PLOT)
 
 /*****************************************************************************/
 
@@ -487,18 +483,16 @@ gog_series1_5d_update (GogObject *obj)
 	unsigned old_num = series->base.num_elements;
 
 	if (series->base.values[1].data != NULL) {
-		vals = go_data_vector_get_values (GO_DATA_VECTOR (series->base.values[1].data));
-		len = go_data_vector_get_len 
-			(GO_DATA_VECTOR (series->base.values[1].data));
+		vals = go_data_get_values (series->base.values[1].data);
+		len = go_data_get_vector_size (series->base.values[1].data);
 	}
 	series->base.num_elements = len;
 
 	if (series->base.plot->desc.series.num_dim == 3) {
 		int tmp = 0;
 		if (series->base.values[2].data != NULL) {
-			vals = go_data_vector_get_values (GO_DATA_VECTOR (series->base.values[2].data));
-			tmp = go_data_vector_get_len 
-				(GO_DATA_VECTOR (series->base.values[2].data));
+			vals = go_data_get_values (series->base.values[2].data);
+			tmp = go_data_get_vector_size (series->base.values[2].data);
 		}
 		if (tmp < len)
 			len = tmp;
@@ -559,7 +553,7 @@ gog_series1_5d_get_property (GObject *obj, guint param_id,
 #include <gtk/gtk.h>
 static void 
 gog_series1_5d_populate_editor (GogObject *obj,
-				GogEditor *editor,
+				GOEditor *editor,
 				GogDataAllocator *dalloc,
 				GOCmdContext *cc)
 {
@@ -577,7 +571,7 @@ gog_series1_5d_populate_editor (GogObject *obj,
 	else
 		g_object_get (G_OBJECT (series->plot), "horizontal", &horizontal, NULL);
 	error_page = gog_error_bar_prefs (series, "errors", horizontal, dalloc, cc);
-	gog_editor_add_page (editor, error_page, _("Error bars"));
+	go_editor_add_page (editor, error_page, _("Error bars"));
 }
 #endif
 
@@ -641,7 +635,7 @@ gog_series1_5d_class_init (GogObjectClass *obj_klass)
 		g_param_spec_object ("errors", 
 			_("Error bars"),
 			_("GogErrorBar *"),
-			GOG_ERROR_BAR_TYPE, 
+			GOG_TYPE_ERROR_BAR, 
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 }
 
@@ -659,7 +653,7 @@ gog_series1_5d_init (GObject *obj)
 
 GSF_DYNAMIC_CLASS (GogSeries1_5d, gog_series1_5d,
 	gog_series1_5d_class_init, gog_series1_5d_init,
-	GOG_SERIES_TYPE)
+	GOG_TYPE_SERIES)
 
 /* Plugin initialization */
 
