@@ -26,7 +26,6 @@
 #include <goffice/graph/gog-view.h>
 #include <goffice/graph/gog-chart-map.h>
 #include <goffice/graph/gog-renderer.h>
-#include <goffice/graph/gog-style.h>
 #include <goffice/graph/gog-axis.h>
 #include <goffice/graph/gog-theme.h>
 #include <goffice/data/go-data.h>
@@ -34,6 +33,8 @@
 #include <goffice/utils/go-color.h>
 #include <goffice/utils/go-marker.h>
 #include <goffice/utils/go-persist.h>
+#include <goffice/utils/go-style.h>
+#include <goffice/utils/go-styled-object.h>
 
 #include <glib/gi18n-lib.h>
 #include <gsf/gsf-impl-utils.h>
@@ -55,19 +56,19 @@ enum {
 typedef GogSeriesElement GogLineSeriesElement;
 typedef GogSeriesElementClass GogLineSeriesElementClass;
 
-#define GOG_LINE_SERIES_ELEMENT_TYPE	(gog_line_series_element_get_type ())
-#define GOG_LINE_SERIES_ELEMENT(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_LINE_SERIES_ELEMENT_TYPE, GogLinelSeriesElement))
-#define GOG_IS_LINE_SERIES_ELEMENT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_LINE_SERIES_ELEMENT_TYPE))
+#define GOG_TYPE_LINE_SERIES_ELEMENT	(gog_line_series_element_get_type ())
+#define GOG_LINE_SERIES_ELEMENT(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_LINE_SERIES_ELEMENT, GogLinelSeriesElement))
+#define GOG_IS_LINE_SERIES_ELEMENT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_LINE_SERIES_ELEMENT))
 GType gog_line_series_element_get_type (void);
 
 static void
-gog_line_series_element_init_style (GogStyledObject *gso, GogStyle *style)
+gog_line_series_element_init_style (GogStyledObject *gso, GOStyle *style)
 {
 	GogSeries const *series = GOG_SERIES (GOG_OBJECT (gso)->parent);
 
 	g_return_if_fail (series != NULL);
 
-	style->interesting_fields = GOG_STYLE_MARKER;
+	style->interesting_fields = GO_STYLE_MARKER;
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
 		style, GOG_OBJECT (gso), GOG_SERIES_ELEMENT (gso)->index, FALSE);
 }
@@ -81,16 +82,16 @@ gog_line_series_element_class_init (GogLineSeriesElementClass *klass)
 
 GSF_DYNAMIC_CLASS (GogLineSeriesElement, gog_line_series_element,
 	gog_line_series_element_class_init, NULL,
-	GOG_SERIES_ELEMENT_TYPE)
+	GOG_TYPE_SERIES_ELEMENT)
 
 /******************************************************************************/
 
 typedef GogView		GogLineSeriesView;
 typedef GogViewClass	GogLineSeriesViewClass;
 
-#define GOG_LINE_SERIES_VIEW_TYPE	(gog_line_series_view_get_type ())
-#define GOG_LINE_SERIES_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_LINE_SERIES_VIEW_TYPE, GogLineSeriesView))
-#define IS_GOG_LINE_SERIES_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_LINE_SERIES_VIEW_TYPE))
+#define GOG_TYPE_LINE_SERIES_VIEW	(gog_line_series_view_get_type ())
+#define GOG_LINE_SERIES_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_LINE_SERIES_VIEW, GogLineSeriesView))
+#define GOG_IS_LINE_SERIES_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_LINE_SERIES_VIEW))
 
 static void
 gog_line_series_view_render (GogView *view, GogViewAllocation const *bbox)
@@ -120,7 +121,7 @@ gog_line_series_view_class_init (GogLineSeriesViewClass *gview_klass)
 
 GSF_DYNAMIC_CLASS (GogLineSeriesView, gog_line_series_view,
 	gog_line_series_view_class_init, NULL,
-	GOG_VIEW_TYPE)
+	GOG_TYPE_VIEW)
 
 /*****************************************************************************/
 
@@ -133,12 +134,12 @@ typedef GogSeries1_5dClass	GogLineSeriesClass;
 static GogStyledObjectClass *series_parent_klass;
 
 GType gog_line_series_get_type (void);
-#define GOG_LINE_SERIES_TYPE	(gog_line_series_get_type ())
-#define GOG_LINE_SERIES(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_LINE_SERIES_TYPE, GogLineSeries))
-#define IS_GOG_LINE_SERIES(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_LINE_SERIES_TYPE))
+#define GOG_TYPE_LINE_SERIES	(gog_line_series_get_type ())
+#define GOG_LINE_SERIES(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_LINE_SERIES, GogLineSeries))
+#define GOG_IS_LINE_SERIES(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_LINE_SERIES))
 
 static void
-gog_line_series_init_style (GogStyledObject *gso, GogStyle *style)
+gog_line_series_init_style (GogStyledObject *gso, GOStyle *style)
 {
 	GogSeries *series = GOG_SERIES (gso);
 	GogLinePlot const *plot;
@@ -150,11 +151,11 @@ gog_line_series_init_style (GogStyledObject *gso, GogStyle *style)
 	plot = GOG_LINE_PLOT (series->plot);
 
 	if (!plot->default_style_has_markers) {
-		style->disable_theming |= GOG_STYLE_MARKER;
+		style->disable_theming |= GO_STYLE_MARKER;
 		if (style->marker.auto_shape) {
 			GOMarker *m = go_marker_new ();
 			go_marker_set_shape (m, GO_MARKER_NONE);
-			gog_style_set_marker (style, m);
+			go_style_set_marker (style, m);
 		}
 	}
 }
@@ -175,7 +176,7 @@ gog_line_series_update (GogObject *obj)
 	}
 	/* update children */
 	for (ptr = obj->children; ptr != NULL; ptr = ptr->next)
-		if (!IS_GOG_SERIES_LINES (ptr->data))
+		if (!GOG_IS_SERIES_LINES (ptr->data))
 			gog_object_request_update (GOG_OBJECT (ptr->data));
 }
 
@@ -185,7 +186,7 @@ gog_line_series_get_xy_data (GogSeries const *series,
 {
 	GogLineSeries *line_ser = GOG_LINE_SERIES (series);
 	*x = line_ser->x;
-	*y = go_data_vector_get_values (GO_DATA_VECTOR (series->values[1].data));
+	*y = go_data_get_values (series->values[1].data);
 	return series->num_elements;
 }
 
@@ -212,7 +213,7 @@ gog_line_series_class_init (GogStyledObjectClass *gso_klass)
 	gog_klass->view_type = gog_line_series_view_get_type ();
 	gog_klass->update = gog_line_series_update;
 	series_klass->get_xy_data = gog_line_series_get_xy_data;
-	series_klass->series_element_type = GOG_LINE_SERIES_ELEMENT_TYPE;
+	series_klass->series_element_type = GOG_TYPE_LINE_SERIES_ELEMENT;
 }
 
 GSF_DYNAMIC_CLASS (GogLineSeries, gog_line_series,
@@ -223,7 +224,7 @@ static void
 child_added_cb (GogLinePlot *plot, GogObject *obj)
 {
 	/* we only accept regression curves for not stacked plots */
-	if (IS_GOG_SERIES (obj) && plot->base.type == GOG_1_5D_NORMAL)
+	if (GOG_IS_SERIES (obj) && plot->base.type == GOG_1_5D_NORMAL)
 		(GOG_SERIES (obj))->acceptable_children =
 					GOG_SERIES_ACCEPT_TREND_LINE;
 }
@@ -330,7 +331,7 @@ gog_line_plot_class_init (GogPlot1_5dClass *gog_plot_1_5d_klass)
 	gog_klass->type_name	= gog_line_plot_type_name;
 	gog_klass->view_type	= gog_line_view_get_type ();
 
-	plot_klass->desc.series.style_fields = GOG_STYLE_LINE | GOG_STYLE_MARKER;
+	plot_klass->desc.series.style_fields = GO_STYLE_LINE | GO_STYLE_MARKER;
 	plot_klass->series_type = gog_line_series_get_type ();
 
 	gog_plot_1_5d_klass->update_stacked_and_percentage =
@@ -367,7 +368,7 @@ gog_area_plot_class_init (GogObjectClass *gog_klass)
 {
 	GogPlotClass *plot_klass = (GogPlotClass *) gog_klass;
 
-	plot_klass->desc.series.style_fields = GOG_STYLE_OUTLINE | GOG_STYLE_FILL;
+	plot_klass->desc.series.style_fields = GO_STYLE_OUTLINE | GO_STYLE_FILL;
 	plot_klass->series_type = gog_series1_5d_get_type ();
 
 	gog_klass->type_name	= gog_area_plot_type_name;
@@ -382,7 +383,7 @@ gog_area_plot_init (GogPlot *plot)
 
 GSF_DYNAMIC_CLASS (GogAreaPlot, gog_area_plot,
 	gog_area_plot_class_init, gog_area_plot_init,
-	GOG_LINE_PLOT_TYPE)
+	GOG_TYPE_LINE_PLOT)
 
 /*****************************************************************************/
 
@@ -418,7 +419,7 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 
 	double **vals;
 	ErrorBarData **error_data;
-	GogStyle **styles;
+	GOStyle **styles;
 	unsigned *lengths;
 	GOPath **paths;
 	GOPath **drop_paths;
@@ -427,7 +428,7 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 	GogObjectRole const *role = NULL;
 	GogSeriesLines **lines;
 
-	double y_zero, drop_lines_y_zero;
+	double y_zero, y_top, y_bottom, drop_lines_y_min, drop_lines_y_max;
 	double abs_sum, sum, value, x, y = 0.;
 	gboolean is_null, is_area_plot;
 
@@ -457,14 +458,18 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 	/* Draw drop lines from point to axis start. See comment in
 	 * GogXYPlotView::render */
 
-	gog_axis_map_get_extents (y_map, &drop_lines_y_zero, NULL); 
-	drop_lines_y_zero = gog_axis_map_to_view (y_map, drop_lines_y_zero);
+	gog_axis_map_get_extents (y_map, &drop_lines_y_min, &drop_lines_y_max); 
+	drop_lines_y_min = gog_axis_map_to_view (y_map, drop_lines_y_min);
+	drop_lines_y_max = gog_axis_map_to_view (y_map, drop_lines_y_max);
+	gog_axis_map_get_extents (y_map, &y_bottom, &y_top);
+	y_bottom = gog_axis_map_to_view (y_map, y_bottom);
+	y_top = gog_axis_map_to_view (y_map, y_top);
 	y_zero = gog_axis_map_get_baseline (y_map); 
 
 	vals    = g_alloca (num_series * sizeof (double *));
 	error_data = g_alloca (num_series * sizeof (ErrorBarData *));
 	lengths = g_alloca (num_series * sizeof (unsigned));
-	styles  = g_alloca (num_series * sizeof (GogStyle *));
+	styles  = g_alloca (num_series * sizeof (GOStyle *));
 	paths	= g_alloca (num_series * sizeof (GOPath *));
 	if (!is_area_plot)
 		points  = g_alloca (num_series * sizeof (Point *));
@@ -482,10 +487,8 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 			continue;
 		}
 
-		vals[i] = go_data_vector_get_values (
-			GO_DATA_VECTOR (series->base.values[1].data));
-		lengths[i] = go_data_vector_get_len (
-			GO_DATA_VECTOR (series->base.values[1].data));
+		vals[i] = go_data_get_values (series->base.values[1].data);
+		lengths[i] = go_data_get_vector_size (series->base.values[1].data);
 		styles[i] = GOG_STYLED_OBJECT (series)->style;
 
 		paths[i] = go_path_new ();
@@ -599,8 +602,34 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 				points[i][j].y = y;
 			}
 			if (lines[i]) {
+				double y_target;
+				GogAxis *axis = GOG_PLOT (model)->axis[GOG_AXIS_X];
+				GogAxisPosition pos = gog_axis_base_get_clamped_position (GOG_AXIS_BASE (axis));
+				switch (pos) {
+				case GOG_AXIS_AT_LOW:
+					y_target = gog_axis_map_is_inverted (y_map)? y_top: y_bottom;
+					break;
+				case GOG_AXIS_CROSS: {
+					GogChartMap *c_map;
+					GogAxisMap *a_map;
+					c_map = gog_chart_map_new (chart, area, axis,
+							gog_axis_base_get_crossed_axis (GOG_AXIS_BASE (axis)),
+							NULL, FALSE);
+					a_map = gog_chart_map_get_axis_map (c_map, 1);
+					y_target = gog_axis_map_to_view (a_map, gog_axis_base_get_cross_location (GOG_AXIS_BASE (axis)));
+					gog_chart_map_free (c_map);
+					break;
+				}
+				case GOG_AXIS_AT_HIGH:
+					y_target = gog_axis_map_is_inverted (y_map)? y_bottom: y_top;
+					break;
+				default:
+					/* this should not occur */
+					y_target = gog_axis_map_to_view (y_map, 0);
+					break;
+				}
 				go_path_move_to (drop_paths[i], x, y);
-				go_path_line_to (drop_paths[i], x, drop_lines_y_zero);
+				go_path_line_to (drop_paths[i], x, y_target);
 			}
 
 		}
@@ -638,7 +667,7 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 	for (i = 0; i < num_series; i++)
 		if (lines[i] != NULL) {
 			gog_renderer_push_style (view->renderer,
-				gog_styled_object_get_style (GOG_STYLED_OBJECT (lines[i])));
+				go_styled_object_get_style (GO_STYLED_OBJECT (lines[i])));
 			gog_series_lines_stroke (lines[i], view->renderer, bbox, drop_paths[i], FALSE);
 			gog_renderer_pop_style (view->renderer);
 			go_path_free (drop_paths[i]);
@@ -684,8 +713,8 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 						gse = GOG_SERIES_ELEMENT (overrides->data);
 						overrides = overrides->next;
 						gog_renderer_push_style (view->renderer,
-							gog_styled_object_get_style (
-								GOG_STYLED_OBJECT (gse)));
+							go_styled_object_get_style (
+								GO_STYLED_OBJECT (gse)));
 				}
 				if (x_margin_min <= x && x <= x_margin_max &&
 				    y_margin_min <= y && y <= y_margin_max) 
@@ -733,4 +762,4 @@ gog_line_view_class_init (GogViewClass *view_klass)
 
 GSF_DYNAMIC_CLASS (GogLineView, gog_line_view,
 	gog_line_view_class_init, NULL,
-	GOG_PLOT_VIEW_TYPE)
+	GOG_TYPE_PLOT_VIEW)
