@@ -25,7 +25,7 @@
 #include <goffice/graph/gog-series-impl.h>
 #include <goffice/graph/gog-view.h>
 #include <goffice/graph/gog-renderer.h>
-#include <goffice/graph/gog-style.h>
+#include <goffice/utils/go-style.h>
 #include <goffice/graph/gog-axis.h>
 #include <goffice/graph/gog-chart.h>
 #include <goffice/graph/gog-chart-map.h>
@@ -110,7 +110,7 @@ gog_box_plot_pref (GogObject *obj,
 	char const *dir = go_plugin_get_dir_name (
 		go_plugins_get_plugin_by_id ("GOffice_plot_boxes"));
 	char	 *path = g_build_filename (dir, "gog-boxplot-prefs.glade", NULL);
-	GladeXML *gui = go_libglade_new (path, "gog_box_plot_prefs", GETTEXT_PACKAGE, cc);
+	GladeXML *gui = go_glade_new (path, "gog_box_plot_prefs", GETTEXT_PACKAGE, cc);
 
 	g_free (path);
         if (gui == NULL)
@@ -154,11 +154,11 @@ gog_box_plot_pref (GogObject *obj,
 
 static void
 gog_box_plot_populate_editor (GogObject *item,
-			      GogEditor *editor,
+			      GOEditor *editor,
 			      G_GNUC_UNUSED GogDataAllocator *dalloc,
 			      GOCmdContext *cc)
 {
-	gog_editor_add_page (editor, gog_box_plot_pref (item, dalloc, cc), _("Properties"));
+	go_editor_add_page (editor, gog_box_plot_pref (item, dalloc, cc), _("Properties"));
 	
 	(GOG_OBJECT_CLASS(gog_box_plot_parent_klass)->populate_editor) (item, editor, dalloc, cc);
 }
@@ -181,9 +181,9 @@ typedef struct {
 } GogBoxPlotSeries;
 typedef GogSeriesClass GogBoxPlotSeriesClass;
 
-#define GOG_BOX_PLOT_SERIES_TYPE	(gog_box_plot_series_get_type ())
-#define GOG_BOX_PLOT_SERIES(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_BOX_PLOT_SERIES_TYPE, GogBoxPlotSeries))
-#define IS_GOG_BOX_PLOT_SERIES(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_BOX_PLOT_SERIES_TYPE))
+#define GOG_TYPE_BOX_PLOT_SERIES	(gog_box_plot_series_get_type ())
+#define GOG_BOX_PLOT_SERIES(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_BOX_PLOT_SERIES, GogBoxPlotSeries))
+#define GOG_IS_BOX_PLOT_SERIES(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_BOX_PLOT_SERIES))
 
 GType gog_box_plot_series_get_type (void);
 
@@ -263,7 +263,7 @@ gog_box_plot_update (GogObject *obj)
 	for (ptr = model->base.series ; ptr != NULL ; ptr = ptr->next) {
 		series = GOG_BOX_PLOT_SERIES (ptr->data);
 		if (!gog_series_is_valid (GOG_SERIES (series)) ||
-			!go_data_vector_get_len (GO_DATA_VECTOR (series->base.values[0].data)))
+			!go_data_get_vector_size (series->base.values[0].data))
 			continue;
 		num_series++;
 		if (series->vals[0] < min)
@@ -300,7 +300,7 @@ gog_box_plot_axis_get_bounds (GogPlot *plot, GogAxisType axis,
 
 	if ((axis == GOG_AXIS_X && model->vertical) ||
 			(axis == GOG_AXIS_Y && !model->vertical)) {
-		GODataScalar *s;
+		GOData *s;
 		GogSeries *series;
 		GSList *ptr;
 		int n = 0;
@@ -309,11 +309,11 @@ gog_box_plot_axis_get_bounds (GogPlot *plot, GogAxisType axis,
 			for (ptr = model->base.series ; ptr != NULL ; ptr = ptr->next) {
 				series = GOG_SERIES (ptr->data);
 				if (!gog_series_is_valid (GOG_SERIES (series)) ||
-					!go_data_vector_get_len (GO_DATA_VECTOR (series->values[0].data)))
+					!go_data_get_vector_size (series->values[0].data))
 					continue;
 				s = gog_series_get_name (series);
 				if (s) {
-					model->names[n] = go_data_scalar_get_str (s);
+					model->names[n] = go_data_get_scalar_string (s);
 					has_names = TRUE;
 				}
 				n++;
@@ -322,8 +322,8 @@ gog_box_plot_axis_get_bounds (GogPlot *plot, GogAxisType axis,
 		bounds->val.maxima = model->num_series + .5;
 		bounds->is_discrete = TRUE;
 		bounds->center_on_ticks = FALSE;
-		return has_names? go_data_vector_str_new (model->names, n, NULL): NULL;
-		
+		return has_names? GO_DATA (go_data_vector_str_new (model->names, n, g_free)): NULL;
+
 	} else {
 		bounds->val.minima = model->min;
 		bounds->val.maxima = model->max;
@@ -397,7 +397,7 @@ gog_box_plot_class_init (GogPlotClass *gog_plot_klass)
 	plot_klass->desc.num_series_max = G_MAXINT;
 	plot_klass->series_type = gog_box_plot_series_get_type ();
 	plot_klass->axis_set = GOG_AXIS_SET_XY;
-	plot_klass->desc.series.style_fields	= GOG_STYLE_LINE | GOG_STYLE_FILL;
+	plot_klass->desc.series.style_fields	= GO_STYLE_LINE | GO_STYLE_FILL;
 	plot_klass->axis_get_bounds   		= gog_box_plot_axis_get_bounds;
 }
 
@@ -410,7 +410,7 @@ gog_box_plot_init (GogBoxPlot *model)
 
 GSF_DYNAMIC_CLASS (GogBoxPlot, gog_box_plot,
 	gog_box_plot_class_init, gog_box_plot_init,
-	GOG_PLOT_TYPE)
+	GOG_TYPE_PLOT)
 
 /*****************************************************************************/
 typedef GogPlotView		GogBoxPlotView;
@@ -429,7 +429,7 @@ gog_box_plot_view_render (GogView *view, GogViewAllocation const *bbox)
 	double min, qu1, med, qu3, max;
 	GOPath *path;
 	GSList *ptr;
-	GogStyle *style;
+	GOStyle *style;
 	int num_ser = 1;
 
 	area = gog_chart_view_get_plot_area (view->parent);
@@ -459,21 +459,21 @@ gog_box_plot_view_render (GogView *view, GogViewAllocation const *bbox)
 	}
 	hrect /= 2.;
 	hbar = hrect / 2.;
-		
+
 	path = go_path_new ();
 	go_path_set_options (path, GO_PATH_OPTIONS_SHARP);
 	for (ptr = model->base.series ; ptr != NULL ; ptr = ptr->next) {
 		series = ptr->data;
 		if (!gog_series_is_valid (GOG_SERIES (series)) ||
-			!go_data_vector_get_len (GO_DATA_VECTOR (series->base.values[0].data)))
+			!go_data_get_vector_size (series->base.values[0].data))
 			continue;
-		style = gog_style_dup (GOG_STYLED_OBJECT (series)->style);
+		style = go_style_dup (GOG_STYLED_OBJECT (series)->style);
 		y = gog_axis_map_to_view (ser_map, num_ser);
 		gog_renderer_push_style (view->renderer, style);
 		if (model->outliers) {
 			double l1, l2, m1, m2, d, r = 2. * hrect * model->radius_ratio;
 			int i = 0;
-		    	style->outline = style->line;
+			style->outline = style->line;
 			d = series->vals[3] - series->vals[1];
 			l1 = series->vals[1] - d * 1.5;
 			l2 = series->vals[1] - d * 3.;
@@ -581,7 +581,7 @@ gog_box_plot_view_class_init (GogViewClass *view_klass)
 
 GSF_DYNAMIC_CLASS (GogBoxPlotView, gog_box_plot_view,
 	gog_box_plot_view_class_init, NULL,
-	GOG_PLOT_VIEW_TYPE)
+	GOG_TYPE_PLOT_VIEW)
 
 /*****************************************************************************/
 
@@ -599,9 +599,8 @@ gog_box_plot_series_update (GogObject *obj)
 	series->svals = NULL;
 
 	if (series->base.values[0].data != NULL) {
-		vals = go_data_vector_get_values (GO_DATA_VECTOR (series->base.values[0].data));
-		len = go_data_vector_get_len 
-			(GO_DATA_VECTOR (series->base.values[0].data));
+		vals = go_data_get_values (series->base.values[0].data);
+		len = go_data_get_vector_size (series->base.values[0].data);
 	}
 	series->base.num_elements = len;
 	if (len > 0) {
@@ -626,7 +625,7 @@ gog_box_plot_series_update (GogObject *obj)
 }
 
 static void
-gog_box_plot_series_init_style (GogStyledObject *gso, GogStyle *style)
+gog_box_plot_series_init_style (GogStyledObject *gso, GOStyle *style)
 {
 	((GogStyledObjectClass*) gog_box_plot_series_parent_klass)->init_style (gso, style);
 
@@ -654,4 +653,4 @@ gog_box_plot_series_class_init (GogObjectClass *obj_klass)
 
 GSF_DYNAMIC_CLASS (GogBoxPlotSeries, gog_box_plot_series,
 	gog_box_plot_series_class_init, NULL,
-	GOG_SERIES_TYPE)
+	GOG_TYPE_SERIES)
